@@ -9,7 +9,9 @@ from polymorphic import PolymorphicModel
 class Room(PolymorphicModel):
     name = models.CharField(max_length=64, unique=True)
     slug = models.SlugField()
+    description = models.TextField()
     subscribers = models.ManyToManyField(User, blank=True)
+    allow_anonymous_access = models.NullBooleanField()
     private = models.NullBooleanField()
     password = models.CharField(max_length=32, blank=True)
 
@@ -22,7 +24,9 @@ class Room(PolymorphicModel):
 
 
 class Message(PolymorphicModel):
-    user = models.ForeignKey(User)
-    date = models.DateTimeField(['%Y-%m-%d %H:%M:%S:%f'])
+    user = models.ForeignKey(User, null=True)
+    # username field is useful to store guest name of unauthenticated users
+    username = models.CharField(max_length=20)
+    date = models.DateTimeField()
     room = models.ForeignKey(Room)
     content = models.CharField(max_length=5000)
